==> haskell-hslua-module-doclayout-1.1.1-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-doclayout
version:              1.1.1
visibility:           public
id:                   hslua-module-doclayout-1.1.1-HqcekceoiO710DYllyC76
key:                  hslua-module-doclayout-1.1.1-HqcekceoiO710DYllyC76
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  338e2d8f89112b2257d602d5a6112a78
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.1.1-HqcekceoiO710DYllyC76
depends:
    base-4.17.2.1 doclayout-0.4.0.1-ARwSAVedBShABEvMPzkmA7
    hslua-2.3.0-1ofKfyLfx0vEav8BH9gRn5 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-doclayout-1.1.1-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-doclayout
version:              1.1.1
visibility:           public
id:                   hslua-module-doclayout-1.1.1-J56ahGVD11qAyKsWPcgX32
key:                  hslua-module-doclayout-1.1.1-J56ahGVD11qAyKsWPcgX32
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  9b879bb90813192d123c0ea395af3102
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.1.1-J56ahGVD11qAyKsWPcgX32
depends:
    base-4.17.2.1 doclayout-0.4.0.1-ARwSAVedBShABEvMPzkmA7
    hslua-2.3.0-AZWSHL1ZfqkEEkzfp7LWKb text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
